import React, { useState, useRef, useEffect } from 'react';
import { makeStyles, Typography, Link, Divider, Button, Grid } from '@material-ui/core';
import { InfoCard, Progress, Page, Header, Content } from '@backstage/core-components';
import Alert from '@material-ui/lab/Alert';
import CircularProgress from '@material-ui/core/CircularProgress';
import { catalogApiRef } from '@backstage/plugin-catalog-react';
import { stringifyEntityRef } from '@backstage/catalog-model';
import { o as opslevelApiRef, a as opslevelPluginApiRef } from './index-c532498e.esm.js';
import { useApi } from '@backstage/core-plugin-api';
import { useAsync, useAsyncFn } from 'react-use';
import Chart from 'react-apexcharts';
import { l as levelColorPalette } from './level_color_helper-6c12375f.esm.js';
import { escape } from 'lodash';
import cloneDeep from 'lodash/cloneDeep';
import { withTheme } from '@material-ui/core/styles';
import opslevelLogo from '../images/opslevel-logo.svg';
import FormControlLabel from '@mui/material/FormControlLabel';
import { Cron } from 'react-js-cron';
import 'react-js-cron/dist/styles.css';
import Accordion from '@mui/material/Accordion';
import AccordionSummary from '@mui/material/AccordionSummary';
import AccordionDetails from '@mui/material/AccordionDetails';
import ExpandMoreIcon from '@material-ui/icons/ExpandMore';
import Switch from '@mui/material/Switch';
import moment from 'moment';
import 'graphql-request';

function useListEntities(kind) {
  const catalogApi = useApi(catalogApiRef);
  return useAsync(async () => {
    return catalogApi.getEntities({
      filter: {
        kind
      }
    });
  });
}
function useListAllEntities() {
  return {
    components: useListEntities("component"),
    users: useListEntities("user"),
    groups: useListEntities("group")
  };
}
async function exportEntity(entity, opslevelApi, appendOutput) {
  appendOutput(startExportMessage(entity));
  const result = await opslevelApi.exportEntity(entity);
  appendOutput(`${finishExportMessage(result)}
`);
}
async function performExport(components, users, groups, opslevelApi, appendOutput) {
  for (const entity of users) {
    await exportEntity(entity, opslevelApi, appendOutput);
  }
  for (const entity of groups) {
    await exportEntity(entity, opslevelApi, appendOutput);
  }
  for (const entity of components) {
    await exportEntity(entity, opslevelApi, appendOutput);
  }
}
function startExportMessage(entity) {
  const entityRef = stringifyEntityRef(entity);
  return `Exporting ${entityRef}... `;
}
function finishExportMessage(result) {
  let message = result.importEntityFromBackstage.actionMessage;
  if (result.importEntityFromBackstage.errors.length) {
    message += ` (error: ${result.importEntityFromBackstage.errors[0].message})`;
  }
  return message;
}
const useStyles$1 = makeStyles((theme) => {
  return {
    outputComponentStyle: {
      backgroundColor: theme.palette.background.default,
      border: "1px solid black",
      marginTop: "1em",
      padding: "0.5em 0.8em",
      whiteSpace: "pre-line"
    }
  };
});
function ExportEntityForm() {
  var _a, _b, _c;
  const opslevelApi = useApi(opslevelApiRef);
  const entityStates = useListAllEntities();
  const error = entityStates.components.error || entityStates.users.error || entityStates.groups.error;
  const loading = entityStates.components.loading || entityStates.users.loading || entityStates.groups.loading;
  const components = ((_a = entityStates.components.value) == null ? void 0 : _a.items) || [];
  const users = ((_b = entityStates.users.value) == null ? void 0 : _b.items) || [];
  const groups = ((_c = entityStates.groups.value) == null ? void 0 : _c.items) || [];
  const entityCount = components.length + users.length + groups.length;
  const [exporting, setExporting] = useState(false);
  const [output, setOutput] = useState("");
  let localOutput = output;
  const { outputComponentStyle } = useStyles$1();
  function appendOutput(message) {
    localOutput += message;
    setOutput(localOutput);
  }
  async function handleSubmit(event) {
    event.preventDefault();
    setExporting(true);
    await performExport(components, users, groups, opslevelApi, appendOutput);
    setExporting(false);
  }
  if (error)
    return /* @__PURE__ */ React.createElement(Alert, {
      severity: "error"
    }, error.message);
  const outputComponent = output.length ? /* @__PURE__ */ React.createElement(Typography, {
    variant: "body1",
    className: outputComponentStyle
  }, output) : null;
  return /* @__PURE__ */ React.createElement("span", null, /* @__PURE__ */ React.createElement(Typography, {
    paragraph: true
  }, /* @__PURE__ */ React.createElement("b", {
    style: { color: "orange" }
  }, "New:"), " Check out our ", /* @__PURE__ */ React.createElement(Link, {
    href: "https://github.com/OpsLevel/backstage-plugin-backend",
    target: "_blank"
  }, "backend plugin"), ", which enables automatic syncing!"), /* @__PURE__ */ React.createElement(Typography, {
    paragraph: true
  }, "The ", /* @__PURE__ */ React.createElement(Link, {
    href: "https://www.opslevel.com",
    target: "_blank"
  }, "OpsLevel"), " Backstage plugin allows you to utilize OpsLevel\u2019s powerful Service Maturity model within your Backstage Instance. After clicking ", /* @__PURE__ */ React.createElement("b", null, "export"), " your Backstage Services will be populated into your OpsLevel account as Services. From there, you can apply ", /* @__PURE__ */ React.createElement(Link, {
    href: "https://www.opslevel.com/docs/checks-and-filters",
    target: "_blank"
  }, "Checks"), " to your Services and begin to build your ", /* @__PURE__ */ React.createElement(Link, {
    href: "https://www.opslevel.com/docs/getting-started-with-rubrics",
    target: "_blank"
  }, "Maturity Rubric"), "."), /* @__PURE__ */ React.createElement(Typography, {
    paragraph: true
  }, "Your ", /* @__PURE__ */ React.createElement(Link, {
    href: "https://www.opslevel.com/docs/categories-and-levels#levels",
    target: "_blank"
  }, "Service Levels"), " will be reflected back into your Backstage Instance via a new ", /* @__PURE__ */ React.createElement("b", null, "Maturity"), " tab when viewing a Component. This tab provides a full ", /* @__PURE__ */ React.createElement(Link, {
    href: "https://www.opslevel.com/docs/maturity-report",
    target: "_blank"
  }, "Maturity Report"), " for your Backstage Services."), /* @__PURE__ */ React.createElement(Typography, {
    paragraph: true
  }, "OpsLevel\u2019s Maturity Report will allow you to unlock valuable insights into the operational health of your Backstage Services as well as provide Service Owners the context they need to ensure they\u2019re meeting their organization's best practices and standards."), /* @__PURE__ */ React.createElement(Divider, null), /* @__PURE__ */ React.createElement("form", {
    noValidate: true,
    autoComplete: "off",
    onSubmit: handleSubmit,
    style: { display: "flex", marginTop: "1em", justifyContent: "space-between" }
  }, /* @__PURE__ */ React.createElement(Button, {
    variant: "contained",
    color: "primary",
    target: "_blank",
    href: "https://app.opslevel.com/reports/rubric"
  }, "View Full Maturity Report in OpsLevel"), /* @__PURE__ */ React.createElement(Button, {
    variant: "contained",
    color: "primary",
    type: "submit",
    disabled: exporting
  }, exporting || loading ? /* @__PURE__ */ React.createElement(CircularProgress, null) : null, "Export ", entityCount, " Entities to OpsLevel")), outputComponent);
}

const mountInitialLevelArray = (levels) => {
  return levels.map((level) => {
    return { [escape(level.name)]: 0 };
  });
};
const updateCategoryAggregateWithLevelCounter = (aggregate, level, serviceCounter) => {
  return aggregate.map((obj) => {
    const currentKey = Object.keys(obj)[0];
    if (level === currentKey) {
      return { [currentKey]: serviceCounter };
    }
    return obj;
  });
};
const servicesByLevel = (levels, servicesLevelCount) => {
  return levels.map((level) => {
    const serviceLevelCount = servicesLevelCount.find(
      (entry) => entry.level.name === level.name
    );
    return { [escape(level.name)]: (serviceLevelCount == null ? void 0 : serviceLevelCount.serviceCount) || 0 };
  });
};
const levelsByCategory = (levels, servicesLevelCountByCategory) => {
  const initialLevelArray = mountInitialLevelArray(levels);
  return servicesLevelCountByCategory.reduce((acc, categoryLevel) => {
    const currentCategory = categoryLevel.category ? categoryLevel.category.name : "Uncategorized";
    const levelName = escape(categoryLevel.level.name);
    const categoryAggregate = acc[currentCategory] || initialLevelArray;
    const newCategoryAggregate = updateCategoryAggregateWithLevelCounter(
      categoryAggregate,
      levelName,
      categoryLevel.serviceCount
    );
    return {
      ...acc,
      [currentCategory]: newCategoryAggregate
    };
  }, {});
};
const fontFamily = [
  "-apple-system",
  "BlinkMacSystemFont",
  "Segoe U",
  "PingFang SC",
  "Hiragino Sans GB",
  "Microsoft YaHei",
  "Helvetica Neue",
  "Helvetica",
  "Arial",
  "sans-serif",
  "Apple Color Emoji",
  "Segoe UI Emoji",
  "Segoe UI Symbol"
].join(", ");

class OverallMaturityOverview extends React.Component {
  constructor(props) {
    super(props);
    let data;
    if (props.loading)
      data = [];
    else
      data = servicesByLevel(props.levels, props.levelCounts);
    this.state = {
      data: data.length > 0 ? data.flatMap((obj) => Object.values(obj)) : [],
      options: {
        chart: {
          foreColor: this.props.theme.palette.text.primary
        },
        plotOptions: {
          pie: {
            expandOnClick: false,
            donut: {
              size: "70%",
              labels: {
                show: true,
                name: {
                  show: false
                },
                value: {
                  show: true,
                  fontFamily
                },
                total: {
                  show: true,
                  showAlways: true,
                  label: void 0,
                  fontSize: "16px",
                  fontFamily,
                  fontWeight: 400,
                  formatter: (w) => {
                    const total = w.globals.seriesTotals.reduce(
                      (a, b) => {
                        return a + b;
                      },
                      0
                    );
                    return `${total} Services`;
                  }
                }
              }
            }
          }
        },
        dataLabels: {
          enabled: true,
          formatter: (val) => {
            const percent = Math.round(val);
            return `${percent}%`;
          }
        },
        colors: levelColorPalette(data.length).map((color) => color.secondary),
        labels: data.length > 0 ? data.flatMap((obj) => Object.keys(obj)) : [],
        legend: {
          fontFamily,
          onItemClick: {
            toggleDataSeries: false
          },
          markers: {
            radius: 2,
            width: 12,
            height: 12
          },
          position: "top",
          formatter: (val, opts) => {
            const percent = opts.w.globals.seriesPercent[opts.seriesIndex];
            let roundedPercent = 0;
            if (!isNaN(percent)) {
              roundedPercent = Math.round(percent);
            }
            return `${val} (${roundedPercent}%)`;
          }
        },
        tooltip: {
          enabled: true,
          theme: "dark",
          fillSeriesColor: false,
          y: {
            formatter: (value) => {
              return `${value} Services`;
            },
            title: {
              formatter: (seriesName) => `${seriesName}:`
            }
          }
        }
      }
    };
  }
  componentDidUpdate(prevProps) {
    if (prevProps.levels !== this.props.levels || prevProps.levelCounts !== this.props.levelCounts || prevProps.loading !== this.props.loading) {
      this.setDataFromProps();
    }
  }
  setDataFromProps() {
    let data;
    if (this.props.loading)
      data = [];
    else
      data = servicesByLevel(this.props.levels, this.props.levelCounts);
    const stateCopy = cloneDeep(this.state);
    this.setState({
      ...stateCopy,
      data: data.length > 0 ? data.flatMap((obj) => Object.values(obj)) : [],
      options: {
        ...stateCopy.options,
        colors: levelColorPalette(data.length).map((color) => color.secondary),
        labels: data.length > 0 ? data.flatMap((obj) => Object.keys(obj)) : []
      }
    });
  }
  render() {
    return /* @__PURE__ */ React.createElement(InfoCard, {
      title: "Overview"
    }, /* @__PURE__ */ React.createElement("div", {
      style: { height: "400px" }
    }, this.props.loading && /* @__PURE__ */ React.createElement(Progress, null), !this.props.loading && /* @__PURE__ */ React.createElement(Chart, {
      options: this.state.options,
      series: this.state.data,
      type: "donut",
      width: "100%",
      height: "400px"
    })));
  }
}
var OverallMaturityOverview$1 = withTheme(OverallMaturityOverview);

class OverallMaturityCategoryBreakdown extends React.Component {
  constructor(props) {
    super(props);
    let data;
    if (props.loading)
      data = {};
    else
      data = levelsByCategory(props.levels, props.categoryLevelCounts);
    this.state = {
      data: this.computeSeries(data),
      options: {
        dataLabels: {
          style: {
            fontSize: 13,
            fontFamily
          }
        },
        plotOptions: {
          bar: {
            horizontal: true
          }
        },
        stroke: {
          width: 1,
          colors: ["#fff"]
        },
        yaxis: {
          labels: {
            style: {
              fontSize: 14,
              fontFamily,
              fontWeight: void 0,
              cssClass: void 0,
              colors: this.props.theme.palette.text.primary
            }
          }
        },
        grid: {
          show: false
        },
        tooltip: {
          theme: "dark",
          y: {
            formatter: (val) => {
              return `${val} Services`;
            }
          }
        },
        fill: {
          opacity: 1
        },
        legend: {
          show: true,
          labels: {
            colors: this.props.theme.palette.text.primary
          }
        },
        colors: levelColorPalette(props.levels.length).map(
          (color) => color.secondary
        ),
        xaxis: {
          categories: Object.keys(data),
          labels: {
            style: {
              fontSize: 14,
              fontFamily,
              fontWeight: void 0,
              cssClass: void 0,
              colors: [this.props.theme.palette.text.primary]
            }
          }
        },
        chart: {
          type: "bar",
          height: "100%",
          stacked: true,
          stackType: "100%",
          toolbar: {
            show: false
          }
        }
      }
    };
  }
  componentDidUpdate(prevProps) {
    if (prevProps.levels !== this.props.levels || prevProps.categoryLevelCounts !== this.props.categoryLevelCounts || prevProps.loading !== this.props.loading) {
      this.setDataFromProps();
    }
  }
  computeSeries(servicesByCategory) {
    const series = [];
    for (const categoryName in servicesByCategory) {
      if (!Object.prototype.hasOwnProperty.call(servicesByCategory, categoryName))
        continue;
      servicesByCategory[categoryName].forEach(
        (serviceLevel) => {
          const level = Object.keys(serviceLevel)[0];
          const serviceCount = serviceLevel[level];
          const existent_serie = series.find((serie) => serie.name === level);
          if (existent_serie) {
            existent_serie.data.push(serviceCount);
          } else {
            series.push({ name: level, data: [serviceCount] });
          }
        }
      );
    }
    return series;
  }
  setDataFromProps() {
    let data;
    if (this.props.loading)
      data = {};
    else
      data = levelsByCategory(
        this.props.levels,
        this.props.categoryLevelCounts
      );
    const stateCopy = cloneDeep(this.state);
    this.setState({
      ...stateCopy,
      data: this.computeSeries(data),
      options: {
        ...stateCopy.options,
        colors: levelColorPalette(this.props.levels.length).map(
          (color) => color.secondary
        ),
        xaxis: {
          ...stateCopy.options.xaxis,
          categories: Object.keys(data)
        }
      }
    });
  }
  render() {
    return /* @__PURE__ */ React.createElement(InfoCard, {
      title: "Category Breakdown"
    }, /* @__PURE__ */ React.createElement("div", {
      style: { height: "400px" }
    }, this.props.loading && /* @__PURE__ */ React.createElement(Progress, null), !this.props.loading && /* @__PURE__ */ React.createElement(Chart, {
      options: this.state.options,
      series: this.state.data,
      type: "bar",
      width: "100%",
      height: "400px"
    })));
  }
}
var OverallMaturityCategoryBreakdown$1 = withTheme(OverallMaturityCategoryBreakdown);

const useStyles = makeStyles((theme) => {
  return {
    paddingCell: {
      paddingLeft: "10px",
      paddingRight: "10px"
    },
    configCell: {
      padding: "10px",
      backgroundColor: theme.palette.background.default,
      minWidth: "280px"
    },
    configHeaderCell: {
      padding: "10px",
      backgroundColor: theme.palette.bursts.backgroundColor.default,
      color: "white"
    },
    accordion: {
      backgroundColor: `${theme.palette.background.default} !important`,
      color: `${theme.palette.text.primary} !important`
    },
    accordionDetails: {
      paddingTop: "0px !important"
    },
    outputComponentStyle: {
      backgroundColor: theme.palette.background.default,
      border: `1px solid ${theme.palette.border}`,
      marginTop: "1em",
      padding: "0.5em 0.8em",
      whiteSpace: "pre-line",
      height: "400px",
      overflowY: "scroll"
    },
    executionNavHeader: {
      marginTop: "10px",
      marginBottom: "10px",
      padding: "10px",
      fontSize: "larger"
    },
    executionNavHeaderText: {
      display: "inline-block"
    },
    cronContainer: {
      marginTop: "10px",
      fontSize: "16px",
      fontFamily: theme.typography.fontFamily,
      letterSpacing: "normal"
    },
    enableLabel: {
      fontFamily: theme.typography.fontFamily,
      fontSize: "16px",
      letterSpacing: "normal",
      marginLeft: "-16px"
    },
    saveButton: {
      marginTop: "20px"
    },
    progress: {
      marginTop: "20px"
    },
    expandIcon: {
      color: theme.palette.text.primary
    },
    paginationLink: {
      fontFamily: theme.typography.fontFamily,
      fontSize: "17px",
      marginTop: "-4px",
      letterSpacing: "normal"
    }
  };
});
const sanitizeSchedule = (schedule) => {
  if (schedule.startsWith("0 "))
    return schedule;
  return `0 ${schedule.substring(schedule.indexOf(" ") + 1)}`;
};
function BackendExportEntitiesForm() {
  const opslevelPluginApi = useApi(opslevelPluginApiRef);
  const [configuration, setConfiguration] = useState(null);
  const [configurationSaving, setConfigurationSaving] = useState(false);
  const [dirty, setDirty] = useState(false);
  const [currentRun, setCurrentRun] = useState(null);
  const [currentRunIndex, setCurrentRunIndex] = useState(0);
  const [runCount, setRunCount] = useState(null);
  const [configExpanded, setConfigExpanded] = useState(false);
  const outputRef = useRef();
  const currentIndexRef = useRef();
  useEffect(() => {
    currentIndexRef.current = currentRunIndex;
  }, [currentRunIndex]);
  const currentRunRef = useRef();
  useEffect(() => {
    currentRunRef.current = currentRun;
  }, [currentRun]);
  const setSchedule = (schedule) => {
    const newSchedule = sanitizeSchedule(schedule);
    if (configuration === null)
      return;
    if (newSchedule !== configuration.auto_sync_schedule) {
      setConfiguration({ auto_sync_enabled: configuration.auto_sync_enabled, auto_sync_schedule: newSchedule });
      setDirty(true);
    }
  };
  const setEnabled = (enabled) => {
    if (configuration === null)
      return;
    setConfiguration({ auto_sync_enabled: enabled, auto_sync_schedule: configuration.auto_sync_schedule });
    setDirty(true);
  };
  const loadRun = (index = currentRunIndex) => {
    opslevelPluginApi.getAutoSyncExecution(index).then((ret) => {
      var _a, _b, _c;
      const contentChanged = ret.rows.length > 0 && ret.rows[0].output !== ((_a = currentRunRef == null ? void 0 : currentRunRef.current) == null ? void 0 : _a.output);
      setCurrentRun(ret.rows.length > 0 ? ret.rows[0] : null);
      setRunCount(ret.total_count);
      setCurrentRunIndex(index);
      if (contentChanged) {
        (_c = (_b = outputRef.current) == null ? void 0 : _b.scroll) == null ? void 0 : _c.call(_b, { top: outputRef.current.scrollHeight, behavior: "smooth" });
      }
    });
  };
  const next = () => {
    setCurrentRun(null);
    setCurrentRunIndex(currentRunIndex + 1);
    loadRun(currentRunIndex + 1);
  };
  const prev = () => {
    setCurrentRun(null);
    setCurrentRunIndex(currentRunIndex - 1);
    loadRun(currentRunIndex - 1);
  };
  const saveConfiguration = () => {
    if (configuration === null)
      return;
    setConfigurationSaving(true);
    opslevelPluginApi.setAutoSyncConfiguration(configuration).then((success) => {
      setDirty(!success);
      setConfigurationSaving(false);
      setConfigExpanded(!success);
    });
  };
  useEffect(() => {
    opslevelPluginApi.getAutoSyncConfiguration().then((response) => setConfiguration(response));
  }, []);
  useEffect(loadRun, []);
  useEffect(() => {
    async function reloadIfFirst() {
      if (currentIndexRef.current === 0)
        loadRun(0);
    }
    setInterval(reloadIfFirst, 1e3 * 5);
  }, []);
  const classes = useStyles();
  return /* @__PURE__ */ React.createElement("span", null, /* @__PURE__ */ React.createElement(Accordion, {
    className: classes.accordion,
    expanded: configExpanded,
    onChange: (_, isExpanded) => setConfigExpanded(isExpanded)
  }, /* @__PURE__ */ React.createElement(AccordionSummary, {
    expandIcon: /* @__PURE__ */ React.createElement(ExpandMoreIcon, {
      className: classes.expandIcon
    })
  }, /* @__PURE__ */ React.createElement(Typography, null, /* @__PURE__ */ React.createElement("b", null, "Configuration", dirty && " - unsaved changes"))), /* @__PURE__ */ React.createElement(AccordionDetails, {
    className: classes.accordionDetails
  }, !!configuration && /* @__PURE__ */ React.createElement("span", null, /* @__PURE__ */ React.createElement(FormControlLabel, {
    value: "start",
    control: /* @__PURE__ */ React.createElement(Switch, {
      color: "primary",
      "data-testid": "autosync-toggle",
      checked: configuration.auto_sync_enabled,
      onChange: (event) => setEnabled(event.target.checked),
      disabled: configurationSaving
    }),
    label: /* @__PURE__ */ React.createElement("span", {
      className: classes.enableLabel
    }, "Enable"),
    labelPlacement: "start"
  }), /* @__PURE__ */ React.createElement("div", {
    className: classes.cronContainer,
    "data-testid": "autosync-cron"
  }, /* @__PURE__ */ React.createElement(Cron, {
    value: configuration.auto_sync_schedule,
    setValue: (val) => {
      setSchedule(val);
    },
    disabled: configurationSaving,
    defaultPeriod: "day",
    allowedDropdowns: ["period", "months", "month-days", "week-days", "hours"],
    allowedPeriods: ["year", "month", "week", "day", "hour"]
  })), /* @__PURE__ */ React.createElement(Button, {
    variant: "contained",
    color: "primary",
    className: classes.saveButton,
    disabled: configurationSaving,
    onClick: saveConfiguration
  }, "Save"), "\xA0"), configurationSaving && /* @__PURE__ */ React.createElement(Progress, {
    className: classes.progress
  }))), (runCount === null || runCount > 0) && [
    /* @__PURE__ */ React.createElement("div", {
      className: classes.executionNavHeader,
      key: "nav-header",
      "data-testid": "execution-header"
    }, currentRunIndex > 0 && /* @__PURE__ */ React.createElement(Link, {
      "data-testid": "execution-header-prev",
      href: "#",
      onClick: prev,
      className: classes.paginationLink
    }, "<<<"), currentRunIndex <= 0 && /* @__PURE__ */ React.createElement("span", {
      "data-testid": "execution-header-prev"
    }, "<<<"), "\xA0", /* @__PURE__ */ React.createElement("div", {
      className: classes.executionNavHeaderText
    }, "Showing execution ", currentRunIndex + 1, " of ", runCount), "\xA0", currentRunIndex < (runCount || 0) - 1 && /* @__PURE__ */ React.createElement(Link, {
      "data-testid": "execution-header-next",
      href: "#",
      onClick: next,
      className: classes.paginationLink
    }, ">>>"), currentRunIndex >= (runCount || 0) - 1 && /* @__PURE__ */ React.createElement("span", {
      "data-testid": "execution-header-next",
      className: classes.paginationLink
    }, ">>>")),
    /* @__PURE__ */ React.createElement("table", {
      key: "info-table"
    }, /* @__PURE__ */ React.createElement("tbody", null, /* @__PURE__ */ React.createElement("tr", null, /* @__PURE__ */ React.createElement("td", {
      className: classes.configHeaderCell
    }, "State"), /* @__PURE__ */ React.createElement("td", {
      "data-testid": "run-state",
      className: classes.configCell
    }, !!currentRun && currentRun.state.charAt(0).toUpperCase() + currentRun.state.slice(1)), /* @__PURE__ */ React.createElement("td", {
      className: classes.paddingCell
    }), /* @__PURE__ */ React.createElement("td", {
      className: classes.configHeaderCell
    }, "Trigger"), /* @__PURE__ */ React.createElement("td", {
      "data-testid": "run-trigger",
      className: classes.configCell
    }, !!currentRun && currentRun.trigger.charAt(0).toUpperCase() + currentRun.trigger.slice(1))), /* @__PURE__ */ React.createElement("tr", null, /* @__PURE__ */ React.createElement("td", {
      className: classes.configHeaderCell
    }, "Started at"), /* @__PURE__ */ React.createElement("td", {
      "data-testid": "run-started-at",
      className: classes.configCell
    }, !!currentRun ? `${moment.utc(currentRun.started_at).format("MMMM Do YYYY, HH:mm:ss")} (UTC)` : ""), /* @__PURE__ */ React.createElement("td", {
      className: classes.paddingCell
    }), /* @__PURE__ */ React.createElement("td", {
      className: classes.configHeaderCell
    }, "Completed at"), /* @__PURE__ */ React.createElement("td", {
      "data-testid": "run-completed-at",
      className: classes.configCell
    }, !!(currentRun == null ? void 0 : currentRun.completed_at) ? `${moment.utc(currentRun.completed_at).format("MMMM Do YYYY, HH:mm:ss")} (UTC)` : "")))),
    /* @__PURE__ */ React.createElement(Typography, {
      variant: "body1",
      className: classes.outputComponentStyle,
      ref: outputRef,
      key: "text-output"
    }, !!currentRun && /* @__PURE__ */ React.createElement("span", {
      "data-testid": "text-output"
    }, currentRun.output)),
    /* @__PURE__ */ React.createElement("div", {
      style: { height: "4px" },
      key: "progress"
    }, !currentRun && /* @__PURE__ */ React.createElement(Progress, null))
  ], runCount !== null && runCount === 0 && /* @__PURE__ */ React.createElement(Typography, {
    "data-testid": "no-run-msg",
    style: { margin: "15px" }
  }, "Export has never run. Please ensure export is enabled in the configuration above."));
}

const OverallMaturity = () => {
  var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j;
  const [data, setData] = useState();
  const [backendPluginPresent, setBackendPluginPresent] = useState(null);
  const opslevelApi = useApi(opslevelApiRef);
  const opslevelPluginApi = useApi(opslevelPluginApiRef);
  const [fetchState, doFetch] = useAsyncFn(async () => {
    const result = await opslevelApi.getServicesReport();
    if (result) {
      setData(result);
    }
  });
  useAsync(doFetch);
  useEffect(() => {
    opslevelPluginApi.isPluginAvailable().then((res) => setBackendPluginPresent(res));
  }, []);
  const header = /* @__PURE__ */ React.createElement("div", {
    style: { display: "flex", alignItems: "center", justifyContent: "space-between" }
  }, "Export Entities to OpsLevel ", /* @__PURE__ */ React.createElement("img", {
    src: opslevelLogo,
    alt: "opslevel logo",
    style: { marginLeft: "0.25em", width: "34px" }
  }));
  return /* @__PURE__ */ React.createElement(Page, {
    themeId: "tool"
  }, /* @__PURE__ */ React.createElement(Header, {
    title: "Service Maturity",
    subtitle: "Powered by OpsLevel"
  }), /* @__PURE__ */ React.createElement(Content, null, /* @__PURE__ */ React.createElement(Grid, {
    container: true,
    spacing: 3
  }, /* @__PURE__ */ React.createElement(Grid, {
    item: true,
    xs: 4
  }, /* @__PURE__ */ React.createElement(OverallMaturityOverview$1, {
    loading: fetchState.loading,
    levels: ((_c = (_b = (_a = data == null ? void 0 : data.account) == null ? void 0 : _a.rubric) == null ? void 0 : _b.levels) == null ? void 0 : _c.nodes) || [],
    levelCounts: ((_e = (_d = data == null ? void 0 : data.account) == null ? void 0 : _d.servicesReport) == null ? void 0 : _e.levelCounts) || []
  })), /* @__PURE__ */ React.createElement(Grid, {
    item: true,
    xs: 8
  }, /* @__PURE__ */ React.createElement(OverallMaturityCategoryBreakdown$1, {
    loading: fetchState.loading,
    levels: ((_h = (_g = (_f = data == null ? void 0 : data.account) == null ? void 0 : _f.rubric) == null ? void 0 : _g.levels) == null ? void 0 : _h.nodes) || [],
    categoryLevelCounts: ((_j = (_i = data == null ? void 0 : data.account) == null ? void 0 : _i.servicesReport) == null ? void 0 : _j.categoryLevelCounts) || []
  })), /* @__PURE__ */ React.createElement(Grid, {
    item: true,
    xs: 12
  }, /* @__PURE__ */ React.createElement(InfoCard, {
    title: header
  }, backendPluginPresent === null && /* @__PURE__ */ React.createElement(Progress, null), backendPluginPresent === true && /* @__PURE__ */ React.createElement(BackendExportEntitiesForm, null), backendPluginPresent === false && /* @__PURE__ */ React.createElement(ExportEntityForm, null))))));
};

export { OverallMaturity };
//# sourceMappingURL=OverallMaturity-92bcb758.esm.js.map
