import { createApiRef, createRouteRef, createPlugin, createApiFactory, configApiRef, createRoutableExtension } from '@backstage/core-plugin-api';
import { stringifyEntityRef } from '@backstage/catalog-model';
import { GraphQLClient, gql } from 'graphql-request';

const opslevelApiRef = createApiRef({
  id: "plugin.opslevel.service"
});
class OpsLevelGraphqlAPI {
  constructor(url) {
    this.url = url;
    this.client = new GraphQLClient(`${this.url}/api/proxy/opslevel/graphql`);
  }
  static fromConfig(config) {
    return new OpsLevelGraphqlAPI(config.getString("backend.baseUrl"));
  }
  getServiceMaturityByAlias(serviceAlias) {
    const query = gql`
      query getServiceMaturityForBackstage($alias: String!) {
        account {
          rubric {
            levels {
              nodes {
                index
                name
                description
              }
            }
          }
          service(alias: $alias) {
            htmlUrl
            maturityReport {
              overallLevel {
                index
                name
                description
              }
              categoryBreakdown {
                category {
                  name
                }
                level {
                  name
                }
              }
            }
            serviceStats {
              rubric {
                checkResults {
                  byLevel {
                    nodes {
                      level {
                        index
                        name
                      }
                      items {
                        nodes {
                          message
                          warnMessage
                          createdAt
                          check {
                            id
                            enableOn
                            name
                            type
                            category {
                              name
                            }
                          }
                          status
                        }
                      }
                    }
                  }
                }
              }
            }
            checkStats {
              totalChecks
              totalPassingChecks
            }
          }
        }
      }
    `;
    return this.client.request(query, { alias: serviceAlias }, { "GraphQL-Visibility": "internal" });
  }
  getServicesReport() {
    const query = gql`
      query servicesReport {
        account {
          rubric {
            levels {
              totalCount
              nodes {
                index
                name
                alias
              }
            }
            categories {
              nodes {
                id
                name
              }
            }
          }
          servicesReport {
            levelCounts {
              level {
                name
              }
              serviceCount
            }
            categoryLevelCounts {
              category {
                name
              }
              level {
                name
                index
              }
              serviceCount
            }
          }
        }
      }    
    `;
    return this.client.request(query, {}, { "GraphQL-Visibility": "internal" });
  }
  exportEntity(entity) {
    const query = gql`
      mutation importEntityFromBackstage($entityRef: String!, $entity: JSON!) {
        importEntityFromBackstage(entityRef: $entityRef, entity: $entity) {
          errors {
            message
          }
          actionMessage
          htmlUrl
        }
      }
    `;
    const entityRef = stringifyEntityRef(entity);
    return this.client.request(query, { entityRef, entity });
  }
}

const opslevelPluginApiRef = createApiRef({
  id: "plugin.opslevel.backend.service"
});
class OpsLevelPluginAPI {
  constructor(url) {
    this.url = url;
    this.url = `${this.url}/api/opslevel`;
  }
  static fromConfig(config) {
    return new OpsLevelPluginAPI(config.getString("backend.baseUrl"));
  }
  async isPluginAvailable() {
    try {
      const response = await fetch(`${this.url}/ping`);
      return response.status === 200;
    } catch {
      return false;
    }
  }
  async getAutoSyncConfiguration() {
    return fetch(`${this.url}/auto_sync`).then((response) => response.json()).then((data) => {
      return data;
    }).catch(() => {
      return null;
    });
  }
  async setAutoSyncConfiguration(configuration) {
    return await fetch(`${this.url}/auto_sync`, {
      method: "POST",
      headers: { "Content-Type": "application/json" },
      body: JSON.stringify(configuration)
    }).then((response) => response.json()).then((data) => {
      return data.status === "ok";
    }).catch(() => {
      return false;
    });
  }
  async getAutoSyncExecution(index) {
    return await fetch(`${this.url}/auto_sync/runs`, {
      method: "POST",
      headers: { "Content-Type": "application/json" },
      body: JSON.stringify({ page_size: 1, page_number: index })
    }).then((response) => response.json()).then((data) => {
      return data;
    }).catch(() => {
      return { total_count: 0, rows: [] };
    });
  }
}

const rootRouteRef = createRouteRef({
  id: "opslevel-maturity"
});

const opslevelMaturityPlugin = createPlugin({
  id: "opslevel-maturity",
  routes: {
    root: rootRouteRef
  },
  apis: [
    createApiFactory({
      api: opslevelApiRef,
      deps: { configApi: configApiRef },
      factory: ({ configApi }) => OpsLevelGraphqlAPI.fromConfig(configApi)
    }),
    createApiFactory({
      api: opslevelPluginApiRef,
      deps: { configApi: configApiRef },
      factory: ({ configApi }) => OpsLevelPluginAPI.fromConfig(configApi)
    })
  ]
});
const OpslevelMaturityPage = opslevelMaturityPlugin.provide(
  createRoutableExtension({
    name: "OpslevelMaturityPage",
    component: () => import('./OverallMaturity-92bcb758.esm.js').then((m) => m.OverallMaturity),
    mountPoint: rootRouteRef
  })
);
const EntityOpsLevelMaturityContent = opslevelMaturityPlugin.provide(
  createRoutableExtension({
    name: "EntityOpsLevelMaturityContent",
    component: () => import('./EntityOpsLevelMaturityContent-7b82034f.esm.js').then(
      (m) => m.EntityOpsLevelMaturityContent
    ),
    mountPoint: rootRouteRef
  })
);

export { EntityOpsLevelMaturityContent as E, OpslevelMaturityPage as O, opslevelPluginApiRef as a, opslevelMaturityPlugin as b, opslevelApiRef as o };
//# sourceMappingURL=index-c532498e.esm.js.map
